Create a tax rate
POST / v1 / tax_rates
Creates a new tax rate.
Parameters
- display _ name string Required The display name of the tax rate, which will be shown to users. The maximum length is 50 characters.
- inclusive boolean Required This specifies if the tax rate is inclusive or exclusive.
- percentage number Required This represents the tax rate percent out of 100.
- active boolean Flag determining whether the tax rate is active or inactive (archived). Inactive tax rates cannot be used with new applications or Checkout Sessions, but will still work for subscriptions and invoices that already have it set.
- country string Two-letter country code ( ISO 3166-1 alpha-2).
- description string An arbitrary string attached to the tax rate for your internal use only. It will not be visible to your customers.
- jurisdiction string The jurisdiction for the tax rate. You can use this label field for tax reporting purposes. It also appears on your customer’s invoice. The maximum length is 50 characters.
- metadata map Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to
metadata. - state string ISO 3166-2 subdivision code, without country prefix. For example, “NY” for New York, United States.
More parameters
- tax _ type enum
Returns
The created tax rate object.
Response
{ "id": "txr_1MzS4RLkdIwHu7ixwvpZ9c2i", "object": "tax_rate", "active": true, "country": null, "created": 1682114687, "description": "VAT Germany", "display_name": "VAT", "inclusive": false, "jurisdiction": "DE", "livemode": false, "metadata": {}, "percentage": 16, "state": null, "tax_type": null}
Update a tax rate
POST / v1 / tax_rates /:id
Updates an existing tax rate.
Parameters
- active boolean Flag determining whether the tax rate is active or inactive (archived). Inactive tax rates cannot be used with new applications or Checkout Sessions, but will still work for subscriptions and invoices that already have it set.
- country string Two-letter country code ( ISO 3166-1 alpha-2).
- description string An arbitrary string attached to the tax rate for your internal use only. It will not be visible to your customers.
- display _ name string The display name of the tax rate, which will be shown to users. The maximum length is 50 characters.
- jurisdiction string The jurisdiction for the tax rate. You can use this label field for tax reporting purposes. It also appears on your customer’s invoice. The maximum length is 50 characters.
- metadata map Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to
metadata. - state string ISO 3166-2 subdivision code, without country prefix. For example, “NY” for New York, United States.
More parameters
- tax _ type enum
Returns
The updated tax rate.
Response
{ "id": "txr_1MzS4RLkdIwHu7ixwvpZ9c2i", "object": "tax_rate", "active": false, "country": null, "created": 1682114687, "description": "VAT Germany", "display_name": "VAT", "effective_percentage": 16, "inclusive": false, "jurisdiction": "DE", "livemode": false, "metadata": {}, "percentage": 16, "state": null, "tax_type": null}
Retrieve a tax rate
GET / v1 / tax_rates /:id
Retrieves a tax rate with the given ID
Parameters
No parameters.
Returns
Returns an tax rate if a valid tax rate ID was provided. Raises an error otherwise.
Response
{ "id": "txr_1MzS4RLkdIwHu7ixwvpZ9c2i", "object": "tax_rate", "active": true, "country": null, "created": 1682114687, "description": "VAT Germany", "display_name": "VAT", "inclusive": false, "jurisdiction": "DE", "livemode": false, "metadata": {}, "percentage": 16, "state": null, "tax_type": null}
